@@ -1,7 +1,8 @@
 #!/bin/bash
+set -e
 
 machine=$(uname -m)
-mkdir build-$machine
-cd build-$machine
+mkdir "build-$machine"
+cd "build-$machine"
 meson ..
 ninja
